
# Slot: subject




URI: [biolink:model_to_disease_mixin_subject](https://w3id.org/biolink/vocab/model_to_disease_mixin_subject)

## Domain and Range

[ModelToDiseaseMixin](ModelToDiseaseMixin.md) ->  <sub>REQ</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [ModelToDiseaseMixin](ModelToDiseaseMixin.md)
